from setuptools import setup

setup(name='zhdan_utils',
      version='0.0.1.2',
      description='Utils include:\n- timer',
      packages=['zhdan_utils'],
      author_email='artur.v.zhdan@gmail.com',
      zip_safe=False)
